==> haskell-ghc-check-0.5.0.8-44-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-CeLDPu5tBnuLq15rxrP34z
key:                  ghc-check-0.5.0.8-CeLDPu5tBnuLq15rxrP34z
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  6cfee05507d8ff5f4b5da7ffab19e1ea
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-CeLDPu5tBnuLq15rxrP34z
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    ghc-9.2.8 ghc-boot-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    process-1.6.16.0 safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx
    template-haskell-2.18.0.0 th-compat-0.1.5-IvB9HRan0b6IGinXr0IRBr
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-check-0.5.0.8-46-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-check.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-check
version:              0.5.0.8
visibility:           public
id:                   ghc-check-0.5.0.8-4KTO5NPIcwgFmWlagpnOyN
key:                  ghc-check-0.5.0.8-4KTO5NPIcwgFmWlagpnOyN
license:              BSD-3-Clause
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:
    detect mismatches between compile-time and run-time versions of the ghc api

description:
    detect mismatches between compile-time and run-time versions of the ghc api

category:             Development
abi:                  e3f78cbd6049879bb700def78dfe1443
exposed:              True
exposed-modules:      GHC.Check GHC.Check.Executable GHC.Check.PackageDb
hidden-modules:       GHC.Check.Util
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-check-0.5.0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-check-0.5.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-check
hs-libraries:         HSghc-check-0.5.0.8-4KTO5NPIcwgFmWlagpnOyN
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    ghc-9.2.8 ghc-boot-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    process-1.6.16.0 safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx
    template-haskell-2.18.0.0 th-compat-0.1.5-4ANVl8iXfARG697rrs9EPv
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-ghc-check/html/ghc-check.haddock
haddock-html:         /usr/share/doc/haskell-ghc-check/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
